@@ -7,11 +7,6 @@ from rapidfuzz.fuzz import partial_ratio
 from json import loads as convert_json_to_dict
 from requests import post
 
-#! the following are used to scrape lyrics
-from requests import get
-import re
-from html import unescape
-
 #! Just for static typing
 from typing import List
 
@@ -47,7 +42,7 @@ def match_percentage(str1: str, str2: str, score_cutoff: float = 0) -> float:
     emojis that usually cause errors
     '''
 
-    #! this will throw an error if either string contains a UTF-8 encoded emoji
+    #! this will throw an error if either string contains a UTF-8 encoded emoji 
     try:
         return partial_ratio(str1, str2, score_cutoff=score_cutoff)
 
@@ -137,7 +132,7 @@ def __query_and_simplify(searchTerm: str, apiKey: str = ytmApiKey) -> List[dict]
     #! Link block (under each 'Result block')
     #!       Contains the video/Album/playlist/Song/Artist link of the
     #!       result as found on YouTube
-
+    
     # Simplify and extract necessary details from senselessly nested YTM response
     #! This process is broken into numbered steps below
 
@@ -173,26 +168,26 @@ def __query_and_simplify(searchTerm: str, apiKey: str = ytmApiKey) -> List[dict]
 
             result = contents['musicResponsiveListItemRenderer'] \
                 ['flexColumns']
+            
 
 
-
-            # Add the linkBlock
-
+            # Add the linkBlock        
+            
             linkBlock = contents['musicResponsiveListItemRenderer'] \
                 ['overlay'] \
                     ['musicItemThumbnailOverlayRenderer'] \
                         ['content'] \
                             ['musicPlayButtonRenderer'] \
                                 ['playNavigationEndpoint']
-
+            
             #! detailsBlock is always a list, so we just append the linkBlock to it
             #! insted of carrying along all the other junk from 'musicResponsiveListItemRenderer'
             result.append(linkBlock)
-
+        
             #! gather resultBlock
             resultBlocks.append(result)
-
-
+    
+    
 
     # 03. Gather available details in the same place
 
@@ -232,14 +227,14 @@ def __query_and_simplify(searchTerm: str, apiKey: str = ytmApiKey) -> List[dict]
         #! 'musicResponsiveListItmeFlexColumnRenderer' should have more that one
         #! sub-block, if not its a dummy, why does the YTM response contain dummies?
         #! I have no clue. We skip these.
-
+        
         #! Remember that we appended the linkBlock to result, treating that like the
         #! other constituents of a result block will lead to errors, hence the 'in
         #! result[:-1]'
         for detail in result[:-1]:
             if len(detail['musicResponsiveListItemFlexColumnRenderer']) < 2:
                 continue
-
+            
             #! if not a dummy, collect all available details
             availableDetails.append(
                 detail['musicResponsiveListItemFlexColumnRenderer'] \
@@ -247,13 +242,13 @@ def __query_and_simplify(searchTerm: str, apiKey: str = ytmApiKey) -> List[dict]
                         ['runs'][0] \
                             ['text']
             )
-
+        
 
 
         # Filterout non-Song/Video results and incomplete results here itself
         #! From what we know about detail order, note that [1] - indicate result type
         if availableDetails[1] in ['Song', 'Video'] and len(availableDetails) == 5:
-
+            
             #! skip if result is in hours instead of minuts (no song is that long)
             if len(availableDetails[4].split(':')) != 2:
                     continue
@@ -287,17 +282,17 @@ def __query_and_simplify(searchTerm: str, apiKey: str = ytmApiKey) -> List[dict]
             #! are a few oddball tracks that are only a few seconds long
             if minStr[0] == '0' and len(minStr) == 2:
                 minStr = minStr[1]
-
+            
             if secStr[0] == '0':
                 secStr = secStr[1]
-
+            
             time = eval(minStr)*60 + eval(secStr)
 
 
 
             # format relevant details
             if availableDetails[1] == 'Song':
-
+            
                 formattedDetails = {
                     'name'      : availableDetails[0],
                     'type'      : 'song',
@@ -307,12 +302,12 @@ def __query_and_simplify(searchTerm: str, apiKey: str = ytmApiKey) -> List[dict]
                     'link'      : resultLink,
                     'position'  : resultPosition
                 }
-
+            
                 if formattedDetails not in simplifiedResults:
                     simplifiedResults.append(formattedDetails)
-
+            
             elif availableDetails[1] == 'Video':
-
+            
                 formattedDetails = {
                     'name'      : availableDetails[0],
                     'type'      : 'video',
@@ -320,12 +315,12 @@ def __query_and_simplify(searchTerm: str, apiKey: str = ytmApiKey) -> List[dict]
                     'link'      : resultLink,
                     'position'  : resultPosition
                 }
-
+            
                 if formattedDetails not in simplifiedResults:
                     simplifiedResults.append(formattedDetails)
-
+            
             #! Things like playlists, albums, etc... just get ignored
-
+            
 
 
     # return the results
@@ -360,7 +355,7 @@ def search_and_order_ytm_results(songName: str, songArtists: List[str],
 
     for artist in songArtists:
         songArtistStr += artist + ', '
-
+    
     #! the ...[:-2] is so that we don't get the last ', ' of searchStrArtists because we
     #! want $artist1, $artist2, ..., $artistN - $songName
     songSearchStr = songArtistStr[:-2] + ' - ' + songName
@@ -379,7 +374,7 @@ def search_and_order_ytm_results(songName: str, songArtists: List[str],
         #! If there are no common words b/w the spotify and YouTube Music name, the song
         #! is a wrong match (Like Ruelle - Madness being matched to Ruelle - Monster, it
         #! happens without this conditional)
-
+        
         #! most song results on youtube go by $artist - $songName, so if the spotify name
         #! has a '-', this function would return True, a common '-' is hardly a 'common
         #! word', so we get rid of it. Lower-caseing all the inputs is to get rid of the
@@ -390,14 +385,14 @@ def search_and_order_ytm_results(songName: str, songArtists: List[str],
         lowerResultName = result['name'].lower()
 
         sentenceAWords = lowerSongName.replace('-', ' ').split(' ')
-
+        
         commonWord = False
 
         #! check for common word
         for word in sentenceAWords:
             if word != '' and word in lowerResultName:
                 commonWord = True
-
+        
         #! if there are no common words, skip result
         if not commonWord:
             continue
@@ -421,12 +416,12 @@ def search_and_order_ytm_results(songName: str, songArtists: List[str],
                 #! artists to song name.
                 if match_percentage(artist.lower(), result['name'].lower(), 85):
                     artistMatchNumber += 1
-
+        
         #! Skip if there are no artists in common, (else, results like 'Griffith Swank -
         #! Madness' will be the top match for 'Ruelle - Madness')
         if artistMatchNumber == 0:
             continue
-
+        
         artistMatch = (artistMatchNumber / len(songArtists) ) * 100
 
 
@@ -494,95 +489,3 @@ def search_and_get_best_match(songName: str, songArtists: List[str],
     #! In theory, the first 'TUPLE' in sortedResults should have the highest match
     #! value, we send back only the link
     return sortedResults[0][0]
-
-
-def get_lyrics(songName: str, artistName: str) -> str:
-    '''
-    `str` `songName`   : Name of the song
-    `str` `artistName` : Name of the primary artist
-
-    RETURNS `str` : lyrics of the song
-    '''
-
-    #! used try, except just in case genius doesn't return any results.
-    try:
-
-        #! Access Token for genius api.
-        geniusHeaders = {
-            'Authorization':
-            'Bearer alXXDbPZtK1m2RrZ8I4k2Hn8Ahsd0Gh_o076HYvcdlBvmc0ULL1H8Z8xRlew5qaG',
-        }
-
-        #! We can't send a search query seperated with spaces.
-        #! So, we seperate song name and artist name using '+' instead of spaces (' ')
-        query = '+'.join((songName+artistName).split(' '))
-
-        #! Base url for a search query.
-        searchURL = 'https://api.genius.com/search'
-
-        #! Get Search response from Genius.
-        geniusResponse = get(
-            searchURL,
-            headers = geniusHeaders,
-            params  = {'q': query}
-        ).json()
-
-        #! Take only the response, leave the status_code.
-        geniusResponse = geniusResponse['response']
-
-        #! We select the best match that genius provides, i.e, the first one.
-        #! Gets the songID of the best match from the genius response
-        #! The song id is actually an int so we've to convert it to a string.
-        bestMatchID = str(geniusResponse['hits'][0]['result']['id'])
-
-        #! and then uses that to get it's URL.
-        bestMatchURL = 'https://api.genius.com/songs/' + bestMatchID
-
-        #! Gets the lyrics page url from genius' response.
-        songURL = get(
-            bestMatchURL,
-            headers=geniusHeaders
-        ).json()['response']['song']['url']
-
-
-        #! Compile All the required Regular Expressions.
-        #! Matches the lyrics.( including html tags)
-        lyricsRegex = re.compile(r'<div class="Lyrics__Container.*?>.*</div><div class="RightSidebar.*?>')
-
-        #! Matches HTML tags.
-        htmlTagRegex = re.compile(r'<.*?>')
-
-        #! Matches Genius Tags like [Chorus]
-        genTagRegex = re.compile(r'\[.*?\]', re.DOTALL)
-
-        #! we use this regex to handle egde cases: (\n Some_lyric \n) -> (Some_Lyric)
-        edgeRegEx = re.compile(r'(\()(\n)(.*?)(\n)(\))')
-
-        #! Gets the genius lyrics page.
-        geniusPage = get(songURL).text
-
-        #! Takes the first string that matches lyricsRegex
-        preLyrics = re.findall(lyricsRegex, geniusPage)[0]
-
-        #! Substitutes HTML Tags for newline characters.
-        preLyrics = htmlTagRegex.sub('\n', preLyrics)
-
-        #! Replace Multiple Newline characters by a single newline character.
-        lyrics = []
-        for i in preLyrics.split('\n'):
-            if i != '\n' and i:
-                lyrics.append(i)
-
-        lyrics = "\n".join(lyrics)
-
-        #! Replaces all HTML escaped characters with unescaped characters.
-        lyrics = unescape(lyrics)
-
-        #! Substitute genius tags for newlines.
-        lyrics = genTagRegex.sub('\n', lyrics)
-        lyrics = edgeRegEx.sub(r'\1\3\5', lyrics)  #! Edge case handling
-    except:
-        lyrics = ''
-
-    #! Removes trailing and leading newlines and spaces.
-    return lyrics.strip()
